[−][src]Struct hermit::kernel::pci::PciAdapter
Fields
bus: u8device: u8vendor_id: u16device_id: u16class_id: u8subclass_id: u8programming_interface_id: u8base_addresses: Vec<PciBar>irq: u8Implementations
impl PciAdapter[src]
pub fn make_bus_master(&self)[src]
pub fn get_bar(&self, baridx: u8) -> Option<PciBar>[src]
Returns the bar at bar-register baridx.
pub fn memory_map_bar(
&self,
index: u8,
no_cache: bool
) -> Option<(VirtAddr, usize)>[src]
&self,
index: u8,
no_cache: bool
) -> Option<(VirtAddr, usize)>
Memory maps pci bar with specified index to identical location in virtual memory.
no_cache determines if we set the Cache Disable flag in the page-table-entry.
Returns (virtual-pointer, size) if successful, else None (if bar non-existent or IOSpace)