[−][src]Struct hermit::x86_64::kernel::irq::ExceptionStackFrame
Represents the exception stack frame pushed by the CPU on exception entry.
Fields
instruction_pointer: u64This value points to the instruction that should be executed when the interrupt
handler returns. For most interrupts, this value points to the instruction immediately
following the last executed instruction. However, for some exceptions (e.g., page faults),
this value points to the faulting instruction, so that the instruction is restarted on
return. See the documentation of the Idt fields for more details.
code_segment: u64The code segment selector, padded with zeros.
cpu_flags: u64The flags register before the interrupt handler was invoked.
stack_pointer: u64The stack pointer at the time of the interrupt.
stack_segment: u64The stack segment descriptor at the time of the interrupt (often zero in 64-bit mode).