[−][src]Struct hermit::fs::Filesystem
Implementations
impl Filesystem[src]
pub const fn new() -> Self[src]
pub fn open(&mut self, path: &str, perms: FilePerms) -> Result<u64, FileError>[src]
Tries to open file at given path (/MOUNTPOINT/internal-path). Looks up MOUNTPOINT in mounted dirs, passes internal-path to filesystem backend Returns the file descriptor of the newly opened file, or an error on failure
pub fn close(&mut self, fd: u64)[src]
pub fn unlink(&mut self, path: &str) -> Result<(), FileError>[src]
Unlinks a file given by path
pub fn mount(
&mut self,
mntpath: &str,
mntobj: Box<dyn PosixFileSystem + Send>
) -> Result<(), ()>[src]
&mut self,
mntpath: &str,
mntobj: Box<dyn PosixFileSystem + Send>
) -> Result<(), ()>
Create new backing-fs at mountpoint mntpath
pub fn fd_op(&mut self, fd: u64, f: impl FnOnce(&mut Box<dyn PosixFile + Send>))[src]
Run closure on file referenced by file descriptor.